@@ -11,7 +11,7 @@ from hashlib import sha1
 from bs4 import BeautifulSoup
 from u115 import conf
 from u115.utils import (get_timestamp, get_utcdatetime, string_to_datetime,
-                        eval_path, quote, utf8_encode, txt_type, PY3)
+                        eval_path, quote, utf8_encode, txt_type, PY3, download)
 
 USER_AGENT = 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_4) \
 AppleWebKit/537.36 (KHTML, like Gecko) Chrome/37.0.2062.94 Safari/537.36'
@@ -128,7 +128,12 @@ class API(object):
     num_tasks_per_page = 30
     web_api_url = 'http://web.api.115.com/files'
 
-    def __init__(self):
+    def __init__(self, auto_logout=True):
+        """
+        :param bool auto_logout: whether to logout automatically when
+            :class:`.API` object is destroyed
+        """
+        self.auto_logout = auto_logout
         self.passport = None
         self.http = RequestHandler()
         self._signatures = {}
@@ -139,6 +144,10 @@ class API(object):
         self._task_count = None
         self._task_quota = None
 
+    def __del__(self):
+        if self.auto_logout and self.has_logged_in:
+            self.logout()
+
     def login(self, username=None, password=None,
               section='default'):
         """
@@ -305,6 +314,17 @@ class API(object):
         data2.update(**data1)
         return _instantiate_uploaded_file(self, data2)
 
+    def download(self, obj, path=None, show_progress=True):
+        """
+        Download a file
+
+        :param obj: :class:`.File` object
+        :param str path: local path
+        :param bool show_progress: whether to show download progress
+        """
+        download(obj.url, path=path, session=self.http.session,
+                 show_progress=show_progress)
+
     def _req_offline_space(self):
         """Required before accessing lixian tasks"""
         url = 'http://115.com/'
@@ -763,6 +783,10 @@ class File(BaseFile):
         """Alias for :func:`File.get_download_url`"""
         return self.get_download_url()
 
+    def download(self):
+        """Download this file"""
+        self.api.download(self)
+
     @property
     def is_torrent(self):
         """Whether the file is a torrent"""
@@ -914,6 +938,11 @@ class Task(Directory):
     :ivar str size_human: human-readable size
     :ivar int status: status code
 
+        * -1: failed
+        * 1: downloading
+        * 2: downloaded
+        * 4: searching resources
+
     """
 
     def __init__(self, api, add_time, file_id, info_hash, last_update,
@@ -969,12 +998,13 @@ class Task(Directory):
 
         :return:
 
-            * `BEING TRANSFERRED`: the tasks is being transferred
-            * `TRANSFERRED`: the tasks has been transferred to downloads \
+            * `DOWNLOADING`: the task is downloading files
+            * `BEING TRANSFERRED`: the task is being transferred
+            * `TRANSFERRED`: the task has been transferred to downloads \
                     directory
-            * `SEARCHING RESOURCES`
-            * `FAILED`
-            * `DELETED`
+            * `SEARCHING RESOURCES`: the task is searching resources
+            * `FAILED`: the task is failed
+            * `DELETED`: the task is deleted
             * `UNKNOWN STATUS`
 
         :rtype: str
@@ -984,6 +1014,8 @@ class Task(Directory):
         if self._deleted:
             return 'DELETED'
         if self.status == 2:
+            res = 'DOWNLOADING'
+        elif self.status == 2:
             if self.move == 0:
                 res = 'BEING TRANSFERRED'
             elif self.move == 1:
@@ -1183,7 +1215,7 @@ def _instantiate_torrent_file(torrent, kwargs):
 
 
 class APIError(Exception):
-    """Error related to API"""
+    """General error related to API"""
     def __init__(self, *args, **kwargs):
         content = kwargs.pop('content', None)
         self.content = content
@@ -1191,7 +1223,7 @@ class APIError(Exception):
 
 
 class TaskError(APIError):
-    """"Task has unstable status or no directory operation"""
+    """Task has unstable status or no directory operation"""
     pass
 
 
